@@ -1,13 +1,17 @@
 """Unit tests for the schema module.
 
-$Id: test_schema.py,v 1.2 2006/09/19 20:07:32 tseaver Exp $
+$Id: test_schema.py,v 1.3 2007/01/23 17:52:22 tseaver Exp $
 """
 import unittest
 
 def test_suite():
     from zope.testing.doctest import DocFileTest
     return unittest.TestSuite((
-            DocFileTest('README.txt',
+            DocFileTest('csv-schema.txt',
+                        package="userschema",),
+            DocFileTest('html-form-schema.txt',
+                        package="userschema",),
+            DocFileTest('etree-schema.txt',
                         package="userschema",),
             ))
 
